@@ -1,4 +1,36 @@
-
+#' Heldout Likelihood by Document Completion
+#' 
+#' Tools for making and evaluating heldout datasets.
+#' 
+#' These functions are used to create and evaluate heldout likelihood using the
+#' document completion method.  The basic idea is to hold out some fraction of
+#' the words in a set of documents, train the model and use the document-level
+#' latent variables to evaluate the probability of the heldout portion. See the
+#' example for the basic workflow.
+#' 
+#' @aliases make.heldout eval.heldout
+#' @param documents the documents to be modeled.
+#' @param vocab the vocabulary item
+#' @param N number of docs to be partially held out
+#' @param proportion proportion of docs to be held out.
+#' @param seed the seed, set for replicability
+#' @examples
+#' 
+#' prep <- prepDocuments(poliblog5k.docs, poliblog5k.voc,
+#'                       poliblog5k.meta,subsample=500,
+#'                       lower.thresh=20,upper.thresh=200)
+#' heldout <- make.heldout(prep$documents, prep$vocab)
+#' documents <- heldout$documents
+#' vocab <- heldout$vocab
+#' meta <- prep$meta
+#' 
+#' stm1<- stm(documents, vocab, 5,
+#'            prevalence =~ rating+ s(day),
+#'            init.type="Random",
+#'            data=meta, max.em.its=5)
+#' eval.heldout(stm1, heldout$missing)
+#' 
+#' @export
 make.heldout <- function(documents, vocab, N=floor(.1*length(documents)), 
                          proportion=.5, seed=NULL) {
   if(!is.null(seed)) set.seed(seed)
@@ -21,8 +53,8 @@ make.heldout <- function(documents, vocab, N=floor(.1*length(documents)),
   }
   missing <- list(index=index, docs=missing)
   #check the vocab
-  indices <- sort(unique(unlist(lapply(documents, "[", 1, ))))
-  
+  indices <- sort(unique(unlist(lapply(documents, function(x) x[1,]))))
+
   #all sorts of nonsense ensues if there is missingness
   if(length(indices)!=length(vocab)) {
     remove <- which(!(1:length(vocab)%in% indices))
@@ -48,9 +80,12 @@ make.heldout <- function(documents, vocab, N=floor(.1*length(documents)),
     vocab <- vocab[indices]
   }
   #hooray.  return some stuff.
-  return(list(documents=documents,vocab=vocab, missing=missing))
+  heldout <- list(documents=documents,vocab=vocab, missing=missing)
+  class(heldout) <- "heldout"
+  return(heldout)
 }
 
+#' @export
 eval.heldout <- function(model, missing) {
   heldout <- vector(length=length(missing$index))
   ntokens <- vector(length=length(missing$index))
@@ -67,8 +102,4 @@ eval.heldout <- function(model, missing) {
   out <- list(expected.heldout=mean(heldout, na.rm=TRUE), doc.heldout=heldout,
               index=missing$index, ntokens=ntokens) #the mean here to deal with 0 length docs
   return(out)
-}
-
-
-
-
+}
\ No newline at end of file
